@@ -1,6 +1,6 @@
 
 use strict ;
-local ($^W) = 1; #use warnings ;
+use warnings ;
 
 use vars qw( $Perl $Inc) ;
 
